@@ -6,19 +6,13 @@
 
 from __future__ import print_function
 
-try:
-    from base64 import encodebytes as base64_encode
-except ImportError:
-    from base64 import encodestring as base64_encode
-
-from binascii import b2a_hex, hexlify
 import json
 import mimetypes
 import os
 import struct
-import sys
 import warnings
 
+from IPython.core.formatters import _safe_get_formatter_method
 from IPython.utils.py3compat import (string_types, cast_bytes_py2, cast_unicode,
                                      unicode_type)
 from IPython.testing.skipdoctest import skip_doctest
@@ -26,9 +20,9 @@ from IPython.testing.skipdoctest import skip_doctest
 __all__ = ['display', 'display_pretty', 'display_html', 'display_markdown',
 'display_svg', 'display_png', 'display_jpeg', 'display_latex', 'display_json',
 'display_javascript', 'display_pdf', 'DisplayObject', 'TextDisplayObject',
-'Pretty', 'HTML', 'Markdown', 'Math', 'Latex', 'SVG', 'ProgressBar', 'JSON', 'Javascript',
+'Pretty', 'HTML', 'Markdown', 'Math', 'Latex', 'SVG', 'JSON', 'Javascript',
 'Image', 'clear_output', 'set_matplotlib_formats', 'set_matplotlib_close',
-'publish_display_data', 'update_display', 'DisplayHandle']
+'publish_display_data']
 
 #-----------------------------------------------------------------------------
 # utility functions
@@ -79,8 +73,8 @@ def _display_mimetype(mimetype, objs, raw=False, metadata=None):
 #-----------------------------------------------------------------------------
 # Main functions
 #-----------------------------------------------------------------------------
-# use * to indicate transient is keyword-only
-def publish_display_data(data, metadata=None, source=None, **kwargs):
+
+def publish_display_data(data, metadata=None, source=None):
     """Publish data and metadata to all frontends.
 
     See the ``display_data`` message in the messaging documentation for
@@ -115,38 +109,19 @@ def publish_display_data(data, metadata=None, source=None, **kwargs):
         to specify metadata about particular representations.
     source : str, deprecated
         Unused.
-    transient : dict, keyword-only
-        A dictionary of transient data, such as display_id.
         """
     from IPython.core.interactiveshell import InteractiveShell
-
-    display_pub = InteractiveShell.instance().display_pub
-
-    # only pass transient if supplied,
-    # to avoid errors with older ipykernel.
-    # TODO: We could check for ipykernel version and provide a detailed upgrade message.
-
-    display_pub.publish(
+    InteractiveShell.instance().display_pub.publish(
         data=data,
         metadata=metadata,
-        **kwargs
     )
 
-
-def _new_id():
-    """Generate a new random text id with urandom"""
-    return b2a_hex(os.urandom(16)).decode('ascii')
-
-
 def display(*objs, **kwargs):
     """Display a Python object in all frontends.
 
     By default all representations will be computed and sent to the frontends.
     Frontends can decide which representation is used and how.
 
-    In terminal IPython this will be similar to using :func:`print`, for use in richer
-    frontends see Jupyter notebook examples with rich display logic.
-
     Parameters
     ----------
     objs : tuple of objects
@@ -154,11 +129,11 @@ def display(*objs, **kwargs):
     raw : bool, optional
         Are the objects to be displayed already mimetype-keyed dicts of raw display data,
         or Python objects that need to be formatted before display? [default: False]
-    include : list, tuple or set, optional
+    include : list or tuple, optional
         A list of format type strings (MIME types) to include in the
         format data dict. If this is set *only* the format types included
         in this list will be computed.
-    exclude : list, tuple or set, optional
+    exclude : list or tuple, optional
         A list of format type strings (MIME types) to exclude in the format
         data dict. If this is set all format types will be computed,
         except for those included in this argument.
@@ -166,147 +141,20 @@ def display(*objs, **kwargs):
         A dictionary of metadata to associate with the output.
         mime-type keys in this dictionary will be associated with the individual
         representation formats, if they exist.
-    transient : dict, optional
-        A dictionary of transient data to associate with the output.
-        Data in this dict should not be persisted to files (e.g. notebooks).
-    display_id : str, bool optional
-        Set an id for the display.
-        This id can be used for updating this display area later via update_display.
-        If given as `True`, generate a new `display_id`
-    kwargs: additional keyword-args, optional
-        Additional keyword-arguments are passed through to the display publisher.
-
-    Returns
-    -------
-
-    handle: DisplayHandle
-        Returns a handle on updatable displays for use with :func:`update_display`,
-        if `display_id` is given. Returns :any:`None` if no `display_id` is given
-        (default).
-
-    Examples
-    --------
-
-    >>> class Json(object):
-    ...     def __init__(self, json):
-    ...         self.json = json
-    ...     def _repr_pretty_(self, pp, cycle):
-    ...         import json
-    ...         pp.text(json.dumps(self.json, indent=2))
-    ...     def __repr__(self):
-    ...         return str(self.json)
-    ...
-
-    >>> d = Json({1:2, 3: {4:5}})
-
-    >>> print(d)
-    {1: 2, 3: {4: 5}}
-
-    >>> display(d)
-    {
-      "1": 2,
-      "3": {
-        "4": 5
-      }
-    }
-
-    >>> def int_formatter(integer, pp, cycle):
-    ...     pp.text('I'*integer)
-
-    >>> plain = get_ipython().display_formatter.formatters['text/plain']
-    >>> plain.for_type(int, int_formatter)
-    <function _repr_pprint at 0x...>
-    >>> display(7-5)
-    II
-
-    >>> del plain.type_printers[int]
-    >>> display(7-5)
-    2
-
-    See Also
-    --------
-
-    :func:`update_display`
-
-    Notes
-    -----
-
-    In Python, objects can declare their textual representation using the
-    `__repr__` method. IPython expands on this idea and allows objects to declare
-    other, rich representations including:
-
-      - HTML
-      - JSON
-      - PNG
-      - JPEG
-      - SVG
-      - LaTeX
-
-    A single object can declare some or all of these representations; all are
-    handled by IPython's display system.
-
-    The main idea of the first approach is that you have to implement special
-    display methods when you define your class, one for each representation you
-    want to use. Here is a list of the names of the special methods and the
-    values they must return:
-
-      - `_repr_html_`: return raw HTML as a string
-      - `_repr_json_`: return a JSONable dict
-      - `_repr_jpeg_`: return raw JPEG data
-      - `_repr_png_`: return raw PNG data
-      - `_repr_svg_`: return raw SVG data as a string
-      - `_repr_latex_`: return LaTeX commands in a string surrounded by "$".
-      - `_repr_mimebundle_`: return a full mimebundle containing the mapping
-      from all mimetypes to data
-
-    When you are directly writing your own classes, you can adapt them for
-    display in IPython by following the above approach. But in practice, you
-    often need to work with existing classes that you can't easily modify.
-
-    You can refer to the documentation on IPython display formatters in order to
-    register custom formatters for already existing types.
-
-    .. versionadded:: 5.4 display available without import
-    .. versionadded:: 6.1 display available without import
-
-    Since IPython 5.4 and 6.1 :func:`display` is automatically made available to
-    the user without import. If you are using display in a document that might
-    be used in a pure python context or with older version of IPython, use the
-    following import at the top of your file::
-
-        from IPython.display import display
-
     """
+    raw = kwargs.get('raw', False)
+    include = kwargs.get('include')
+    exclude = kwargs.get('exclude')
+    metadata = kwargs.get('metadata')
+
     from IPython.core.interactiveshell import InteractiveShell
-    
-    if not InteractiveShell.initialized():
-        # Directly print objects.
-        print(*objs)
-        return
-    
-    raw = kwargs.pop('raw', False)
-    include = kwargs.pop('include', None)
-    exclude = kwargs.pop('exclude', None)
-    metadata = kwargs.pop('metadata', None)
-    transient = kwargs.pop('transient', None)
-    display_id = kwargs.pop('display_id', None)
-    if transient is None:
-        transient = {}
-    if display_id:
-        if display_id is True:
-            display_id = _new_id()
-        transient['display_id'] = display_id
-    if kwargs.get('update') and 'display_id' not in transient:
-        raise TypeError('display_id required for update_display')
-    if transient:
-        kwargs['transient'] = transient
 
     if not raw:
         format = InteractiveShell.instance().display_formatter.format
 
     for obj in objs:
         if raw:
-            publish_display_data(data=obj, metadata=metadata, **kwargs)
+            publish_display_data(data=obj, metadata=metadata)
         else:
             format_dict, md_dict = format(obj, include=include, exclude=exclude)
             if not format_dict:
@@ -315,84 +163,7 @@ def display(*objs, **kwargs):
             if metadata:
                 # kwarg-specified metadata gets precedence
                 _merge(md_dict, metadata)
-            publish_display_data(data=format_dict, metadata=md_dict, **kwargs)
-    if display_id:
-        return DisplayHandle(display_id)
-
-
-# use * for keyword-only display_id arg
-def update_display(obj, **kwargs):
-    """Update an existing display by id
-
-    Parameters
-    ----------
-
-    obj:
-        The object with which to update the display
-    display_id: keyword-only
-        The id of the display to update
-
-    See Also
-    --------
-
-    :func:`display`
-    """
-    sentinel = object()
-    display_id = kwargs.pop('display_id', sentinel)
-    if display_id is sentinel:
-        raise TypeError("update_display() missing 1 required keyword-only argument: 'display_id'")
-    kwargs['update'] = True
-    display(obj, display_id=display_id, **kwargs)
-
-
-class DisplayHandle(object):
-    """A handle on an updatable display
-
-    Call `.update(obj)` to display a new object.
-
-    Call `.display(obj`) to add a new instance of this display,
-    and update existing instances.
-
-    See Also
-    --------
-
-        :func:`display`, :func:`update_display`
-
-    """
-
-    def __init__(self, display_id=None):
-        if display_id is None:
-            display_id = _new_id()
-        self.display_id = display_id
-
-    def __repr__(self):
-        return "<%s display_id=%s>" % (self.__class__.__name__, self.display_id)
-
-    def display(self, obj, **kwargs):
-        """Make a new display with my id, updating existing instances.
-        
-        Parameters
-        ----------
-        
-        obj:
-            object to display
-        **kwargs:
-            additional keyword arguments passed to display
-        """
-        display(obj, display_id=self.display_id, **kwargs)
-
-    def update(self, obj, **kwargs):
-        """Update existing displays with my id
-        
-        Parameters
-        ----------
-        
-        obj:
-            object to display
-        **kwargs:
-            additional keyword arguments passed to update_display
-        """
-        update_display(obj, display_id=self.display_id, **kwargs)
+            publish_display_data(data=format_dict, metadata=md_dict)
 
 
 def display_pretty(*objs, **kwargs):
@@ -414,9 +185,6 @@ def display_pretty(*objs, **kwargs):
 
 def display_html(*objs, **kwargs):
     """Display the HTML representation of an object.
-    
-    Note: If raw=False and the object does not have a HTML
-    representation, no HTML will be shown.
 
     Parameters
     ----------
@@ -664,8 +432,8 @@ class TextDisplayObject(DisplayObject):
 
 class Pretty(TextDisplayObject):
 
-    def _repr_pretty_(self, pp, cycle):
-        return pp.text(self.data)
+    def _repr_pretty_(self):
+        return self.data
 
 
 class HTML(TextDisplayObject):
@@ -703,7 +471,6 @@ class Latex(TextDisplayObject):
 
 class SVG(DisplayObject):
 
-    _read_flags = 'rb'
     # wrap data in a property, which extracts the <svg> tag, discarding
     # document headers
     _data = None
@@ -735,67 +502,6 @@ class SVG(DisplayObject):
     def _repr_svg_(self):
         return self.data
 
-class ProgressBar(DisplayObject):
-    """Progressbar supports displaying a progressbar like element 
-    """
-    def __init__(self, total):
-        """Creates a new progressbar
-        
-        Parameters
-        ----------
-        total : int
-            maximum size of the progressbar
-        """
-        self.total = total
-        self._progress = 0
-        self.html_width = '60ex'
-        self.text_width = 60
-        self._display_id = hexlify(os.urandom(8)).decode('ascii')
-
-    def __repr__(self):
-        fraction = self.progress / self.total
-        filled = '=' * int(fraction * self.text_width)
-        rest = ' ' * (self.text_width - len(filled))
-        return '[{}{}] {}/{}'.format(
-            filled, rest,
-            self.progress, self.total,
-        )
-
-    def _repr_html_(self):
-        return "<progress style='width:{}' max='{}' value='{}'></progress>".format(
-            self.html_width, self.total, self.progress)
-
-    def display(self):
-        display(self, display_id=self._display_id)
-
-    def update(self):
-        display(self, display_id=self._display_id, update=True)
-
-    @property
-    def progress(self):
-        return self._progress
-
-    @progress.setter
-    def progress(self, value):
-        self._progress = value
-        self.update()
-
-    def __iter__(self):
-        self.display()
-        self._progress = -1 # First iteration is 0
-        return self
-
-    def __next__(self):
-        """Returns current value and increments display by one."""
-        self.progress += 1
-        if self.progress < self.total:
-            return self.progress
-        else:
-            raise StopIteration()
-            
-    def next(self):
-        """Python 2 compatibility"""
-        return self.__next__() 
 
 class JSON(DisplayObject):
     """JSON expects a JSON-able dict or list
@@ -931,7 +637,7 @@ class Image(DisplayObject):
     _FMT_PNG = u'png'
     _ACCEPTABLE_EMBEDDINGS = [_FMT_JPEG, _FMT_PNG]
 
-    def __init__(self, data=None, url=None, filename=None, format=None,
+    def __init__(self, data=None, url=None, filename=None, format=u'png',
                  embed=None, width=None, height=None, retina=False,
                  unconfined=False, metadata=None):
         """Create a PNG/JPEG image object given raw data.
@@ -964,9 +670,9 @@ class Image(DisplayObject):
 
             Note that QtConsole is not able to display images if `embed` is set to `False`
         width : int
-            Width in pixels to which to constrain the image in html
+            Width to which to constrain the image in html
         height : int
-            Height in pixels to which to constrain the image in html
+            Height to which to constrain the image in html
         retina : bool
             Automatically set the width and height to half of the measured
             width and height.
@@ -1008,27 +714,17 @@ class Image(DisplayObject):
         else:
             ext = None
 
-        if format is None:
-            if ext is not None:
-                if ext == u'jpg' or ext == u'jpeg':
-                    format = self._FMT_JPEG
-                elif ext == u'png':
-                    format = self._FMT_PNG
-                else:
-                    format = ext.lower()
-            elif isinstance(data, bytes):
-                # infer image type from image data header,
-                # only if format has not been specified.
-                if data[:2] == _JPEG:
-                    format = self._FMT_JPEG
-
-        # failed to detect format, default png
-        if format is None:
-            format = 'png'
-
-        if format.lower() == 'jpg':
-            # jpg->jpeg
-            format = self._FMT_JPEG
+        if ext is not None:
+            format = ext.lower()
+            if ext == u'jpg' or ext == u'jpeg':
+                format = self._FMT_JPEG
+            if ext == u'png':
+                format = self._FMT_PNG
+        elif isinstance(data, bytes) and format == 'png':
+            # infer image type from image data header,
+            # only if format might not have been specified.
+            if data[:2] == _JPEG:
+                format = 'jpeg'
 
         self.format = unicode_type(format).lower()
         self.embed = embed if embed is not None else (url is None)
@@ -1111,7 +807,7 @@ class Image(DisplayObject):
 
 class Video(DisplayObject):
 
-    def __init__(self, data=None, url=None, filename=None, embed=False, mimetype=None):
+    def __init__(self, data=None, url=None, filename=None, embed=None, mimetype=None):
         """Create a video object given raw data or an URL.
 
         When this object is returned by an input cell or passed to the
@@ -1121,54 +817,41 @@ class Video(DisplayObject):
         Parameters
         ----------
         data : unicode, str or bytes
-            The raw video data or a URL or filename to load the data from.
-            Raw data will require passing `embed=True`.
+            The raw image data or a URL or filename to load the data from.
+            This always results in embedded image data.
         url : unicode
-            A URL for the video. If you specify `url=`,
-            the image data will not be embedded.
+            A URL to download the data from. If you specify `url=`,
+            the image data will not be embedded unless you also specify `embed=True`.
         filename : unicode
-            Path to a local file containing the video.
-            Will be interpreted as a local URL unless `embed=True`.
+            Path to a local file to load the data from.
+            Videos from a file are always embedded.
         embed : bool
-            Should the video be embedded using a data URI (True) or be
-            loaded using a <video> tag (False).
+            Should the image data be embedded using a data URI (True) or be
+            loaded using an <img> tag. Set this to True if you want the image
+            to be viewable later with no internet connection in the notebook.
 
-            Since videos are large, embedding them should be avoided, if possible.
-            You must confirm embedding as your intention by passing `embed=True`.
-
-            Local files can be displayed with URLs without embedding the content, via::
-
-                Video('./video.mp4')
+            Default is `True`, unless the keyword argument `url` is set, then
+            default value is `False`.
 
+            Note that QtConsole is not able to display images if `embed` is set to `False`
         mimetype: unicode
-            Specify the mimetype for embedded videos.
-            Default will be guessed from file extension, if available.
-
+            Specify the mimetype in case you load in a encoded video.
         Examples
         --------
-
         Video('https://archive.org/download/Sita_Sings_the_Blues/Sita_Sings_the_Blues_small.mp4')
         Video('path/to/video.mp4')
-        Video('path/to/video.mp4', embed=True)
-        Video(b'raw-videodata', embed=True)
+        Video('path/to/video.mp4', embed=False)
         """
-        if url is None and isinstance(data, string_types) and data.startswith(('http:', 'https:')):
+        if url is None and (data.startswith('http') or data.startswith('https')):
             url = data
             data = None
+            embed = False
         elif os.path.exists(data):
             filename = data
             data = None
-        
-        if data and not embed:
-            msg = ''.join([
-                "To embed videos, you must pass embed=True ",
-                "(this may make your notebook files huge)\n",
-                "Consider passing Video(url='...')",
-            ])
-            raise ValueError(msg)
 
         self.mimetype = mimetype
-        self.embed = embed
+        self.embed = embed if embed is not None else (filename is not None)
         super(Video, self).__init__(data=data, url=url, filename=filename)
 
     def _repr_html_(self):
@@ -1180,27 +863,20 @@ class Video(DisplayObject):
       Your browser does not support the <code>video</code> element.
     </video>""".format(url)
             return output
-        
-        # Embedded videos are base64-encoded.
-        mimetype = self.mimetype
+        # Embedded videos uses base64 encoded videos.
         if self.filename is not None:
-            if not mimetype:
-                mimetype, _ = mimetypes.guess_type(self.filename)
-            
-            with open(self.filename, 'rb') as f:
-                video = f.read()
+            mimetypes.init()
+            mimetype, encoding = mimetypes.guess_type(self.filename)
+
+            video = open(self.filename, 'rb').read()
+            video_encoded = video.encode('base64')
         else:
-            video = self.data
-        if isinstance(video, unicode_type):
-            # unicode input is already b64-encoded
-            b64_video = video
-        else:
-            b64_video = base64_encode(video).decode('ascii').rstrip()
-        
+            video_encoded = self.data
+            mimetype = self.mimetype
         output = """<video controls>
  <source src="data:{0};base64,{1}" type="{0}">
  Your browser does not support the video tag.
- </video>""".format(mimetype, b64_video)
+ </video>""".format(mimetype, video_encoded)
         return output
 
     def reload(self):
@@ -1225,10 +901,11 @@ def clear_output(wait=False):
     if InteractiveShell.initialized():
         InteractiveShell.instance().display_pub.clear_output(wait)
     else:
-        print('\033[2K\r', end='')
-        sys.stdout.flush()
-        print('\033[2K\r', end='')
-        sys.stderr.flush()
+        from IPython.utils import io
+        print('\033[2K\r', file=io.stdout, end='')
+        io.stdout.flush()
+        print('\033[2K\r', file=io.stderr, end='')
+        io.stderr.flush()
 
 
 @skip_doctest
