@@ -41,7 +41,7 @@ class Audio(DisplayObject):
     filename : unicode
         Path to a local file to load the data from.
     embed : boolean
-        Should the audio data be embedded using a data URI (True) or should
+        Should the image data be embedded using a data URI (True) or should
         the original source be referenced. Set this to True if you want the
         audio to playable later with no internet connection in the notebook.
 
@@ -251,26 +251,12 @@ class YouTubeVideo(IFrame):
         start=int(timedelta(hours=1, minutes=46, seconds=40).total_seconds())
 
     Other parameters can be provided as documented at
-    https://developers.google.com/youtube/player_parameters#Parameters
-    
-    When converting the notebook using nbconvert, a jpeg representation of the video
-    will be inserted in the document.
+    https://developers.google.com/youtube/player_parameters#parameter-subheader
     """
 
     def __init__(self, id, width=400, height=300, **kwargs):
-        self.id=id
         src = "https://www.youtube.com/embed/{0}".format(id)
         super(YouTubeVideo, self).__init__(src, width, height, **kwargs)
-    
-    def _repr_jpeg_(self):
-        try:
-            from urllib.request import urlopen  # Py3
-        except ImportError:
-            from urllib2 import urlopen
-        try:
-            return urlopen("https://img.youtube.com/vi/{id}/hqdefault.jpg".format(id=self.id)).read()
-        except IOError:
-            return None
 
 class VimeoVideo(IFrame):
     """
@@ -324,11 +310,11 @@ class FileLink(object):
         ----------
         path : str
             path to the file or directory that should be formatted
-        url_prefix : str
+        directory_prefix : str
             prefix to be prepended to all files to form a working link [default:
-            '']
+            'files']
         result_html_prefix : str
-            text to append to beginning to link [default: '']
+            text to append to beginning to link [default: none]
         result_html_suffix : str
             text to append at the end of link [default: '<br>']
         """
