@@ -104,8 +104,8 @@ or :okwarning: options:
         In [1]: 1/0
         In [2]: # raise warning.
 
-To Do
------
+ToDo
+----
 
 - Turn the ad-hoc test() function into a real test suite.
 - Break up ipython-specific functionality from matplotlib stuff into better
@@ -127,7 +127,6 @@ from __future__ import print_function
 
 # Stdlib
 import atexit
-import errno
 import os
 import re
 import sys
@@ -136,10 +135,17 @@ import ast
 import warnings
 import shutil
 
+# To keep compatibility with various python versions
+try:
+    from hashlib import md5
+except ImportError:
+    from md5 import md5
 
 # Third-party
+import sphinx
 from docutils.parsers.rst import directives
-from docutils.parsers.rst import Directive
+from docutils import nodes
+from sphinx.util.compat import Directive
 
 # Our own
 from traitlets.config import Config
@@ -279,7 +285,6 @@ class EmbeddedSphinxShell(object):
 
         # Create config object for IPython
         config = Config()
-        config.HistoryManager.hist_file = ':memory:'
         config.InteractiveShell.autocall = False
         config.InteractiveShell.autoindent = False
         config.InteractiveShell.colors = 'NoColor'
@@ -295,6 +300,15 @@ class EmbeddedSphinxShell(object):
         IP = InteractiveShell.instance(config=config, profile_dir=profile)
         atexit.register(self.cleanup)
 
+        # io.stdout redirect must be done after instantiating InteractiveShell
+        io.stdout = self.cout
+        io.stderr = self.cout
+
+        # For debugging, so we can see normal output, use this:
+        #from IPython.utils.io import Tee
+        #io.stdout = Tee(self.cout, channel='stdout') # dbg
+        #io.stderr = Tee(self.cout, channel='stderr') # dbg
+
         # Store a few parts of IPython we'll need.
         self.IP = IP
         self.user_ns = self.IP.user_ns
@@ -358,9 +372,9 @@ class EmbeddedSphinxShell(object):
         source_dir = self.source_dir
         saveargs = decorator.split(' ')
         filename = saveargs[1]
-        # insert relative path to image file in source (as absolute path for Sphinx)
-        outfile = '/' + os.path.relpath(os.path.join(savefig_dir,filename),
-                                        source_dir)
+        # insert relative path to image file in source
+        outfile = os.path.relpath(os.path.join(savefig_dir,filename),
+                    source_dir)
 
         imagerows = ['.. image:: %s'%outfile]
 
@@ -842,9 +856,14 @@ class IPythonDirective(Directive):
         config = self.state.document.settings.env.config
 
         # get config variables to set figure output directory
+        confdir = self.state.document.settings.env.app.confdir
         savefig_dir = config.ipython_savefig_dir
-        source_dir = self.state.document.settings.env.srcdir
-        savefig_dir = os.path.join(source_dir, savefig_dir)
+        source_dir = os.path.dirname(self.state.document.current_source)
+        if savefig_dir is None:
+            savefig_dir = config.html_static_path
+        if isinstance(savefig_dir, list):
+            savefig_dir = savefig_dir[0] # safe to assume only one path?
+        savefig_dir = os.path.join(confdir, savefig_dir)
 
         # get regex and prompt stuff
         rgxin      = config.ipython_rgxin
@@ -863,19 +882,15 @@ class IPythonDirective(Directive):
         (savefig_dir, source_dir, rgxin, rgxout, promptin, promptout,
          mplbackend, exec_lines, hold_count) = self.get_config_options()
 
-        try:
-            os.makedirs(savefig_dir)
-        except OSError as e:
-            if e.errno != errno.EEXIST:
-                raise
-
         if self.shell is None:
             # We will be here many times.  However, when the
             # EmbeddedSphinxShell is created, its interactive shell member
             # is the same for each instance.
 
-            if mplbackend and 'matplotlib.backends' not in sys.modules:
+            if mplbackend:
                 import matplotlib
+                # Repeated calls to use() will not hurt us since `mplbackend`
+                # is the same each time.
                 matplotlib.use(mplbackend)
 
             # Must be called after (potentially) importing matplotlib and
@@ -891,6 +906,7 @@ class IPythonDirective(Directive):
         if not self.state.document.current_source in self.seen_docs:
             self.shell.IP.history_manager.reset()
             self.shell.IP.execution_count = 1
+            self.shell.IP.prompt_manager.width = 0
             self.seen_docs.add(self.state.document.current_source)
 
         # and attach to shell so we don't have to pass them around
@@ -977,7 +993,7 @@ def setup(app):
     setup.app = app
 
     app.add_directive('ipython', IPythonDirective)
-    app.add_config_value('ipython_savefig_dir', 'savefig', 'env')
+    app.add_config_value('ipython_savefig_dir', None, 'env')
     app.add_config_value('ipython_rgxin',
                          re.compile('In \[(\d+)\]:\s?(.*)\s*'), 'env')
     app.add_config_value('ipython_rgxout',
@@ -998,9 +1014,6 @@ def setup(app):
 
     app.add_config_value('ipython_holdcount', True, 'env')
 
-    metadata = {'parallel_read_safe': True, 'parallel_write_safe': True}
-    return metadata
-
 # Simple smoke test, needs to be converted to a proper automatic test.
 def test():
 
